Beaker provides several ways to authenticate. LinchPin supports these methods.

* Kerberos
* OAuth2

.. note:: LinchPin doesn't support the username/password authentication
   mechanism. It's also not recommended by the Beaker Project, except for
   initial setup.

